using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using Infragistics.Win.UltraWinListView;


namespace Infragistics.Win.Samples
{
	#region WinListViewDropTarget class
	/// <summary>
	/// Class which implements the IDropTarget interface for the WinListView control.
	/// </summary>
	public class WinListViewDropTarget : DragDropManager.IDropTarget
	{
		#region Member variables
		
		private UltraListView _listView = null;
		
		#endregion Member variables
	
		#region Constructors

		/// <summary>
		/// Creates a new instance of the <see cref="WinListViewDropTarget"/> class.
		/// </summary>
		/// <param name="listView">The UltraListView control with which this instance is associated.</param>
		public WinListViewDropTarget( UltraListView listView )
		{
			if ( listView == null )
				throw new ArgumentNullException( "listView" );

			this._listView = listView;
		}

		#endregion Constructors

		#region IDropTarget interface implementation

		//	Implements the Control property.
		UltraControlBase DragDropManager.IDropTarget.Control
		{
			get{ return this._listView; }
		}

		//	Handles the OnDropTargetNotify method.
		void DragDropManager.IDropTarget.OnDropTargetNotify( DragDropManager.DropTargetNotifyInfo info )
		{
			UltraListView listView = this._listView;

			switch ( info.DropTargetNotification )
			{
				//	If the drop notification type is 'DragOver', read the state of the
				//	Control key and set the 'Effect' property accordingly, so that the
				//	drag source knows which drag cursor to display, and also whether the
				//	drag data should be removed from the drag source info.
				case DragDropManager.DropTargetNotification.DragOver:
				{
					info.Effect = info.IsControlKeyPressed ? DragDropEffects.Copy : DragDropEffects.Move;
				}
				break;

				//	If the drop notification type is 'DragDrop', add the items to
				//	the drop target's Items collection.
				case DragDropManager.DropTargetNotification.DragDrop:
				{
					IDataObject dataObject = info.Data as IDataObject;
					UltraListViewItem[] items = dataObject.GetData( typeof(UltraListViewItem[]) ) as UltraListViewItem[];
					if ( items != null )
					{
						//	If we are copying the items, clone each oninfo...note that for this
						//	demonstration we will not include subitems, but this could be easily
						//	changed to support this.
						if ( info.Effect == DragDropEffects.Copy )
						{
							for ( int i = items.Length - 1; i >= 0; i -- )
							{
								items[i] = items[i].Clone();
							}
						}

						listView.Items.AddRange( items );
					}
				}
				break;
			}
		}
		#endregion	IDropTarget interface implementation

	}
	#endregion WinListViewDropTarget class
}